diff --git a/config/config.sample.php b/config/config.sample.php
index 5792381e4d776923f3a63cc2b66892a3581fa9ca..6a1ca06ef0c668c4708d079805ca98601f49a6bd 100644
--- a/config/config.sample.php
+++ b/config/config.sample.php
@@ -1615,10 +1615,15 @@ $CONFIG = [
 'theme' => '',
 
 /**
  * The default cipher for encrypting files. Currently AES-128-CFB and
  * AES-256-CFB are supported.
  */
-'cipher' => 'AES-256-CFB',
+'cipher' => 'AES-256-CTR',
 
 /**
  * The minimum Nextcloud desktop client version that will be allowed to sync with
@@ -1615,10 +1615,15 @@ $CONFIG = [
 
 /**
- * The default cipher for encrypting files. Currently AES-128-CFB and
- * AES-256-CFB are supported.
+ * The default cipher for encrypting files. Currently supported are:
+ *  - AES-256-CTR
+ *  - AES-128-CTR
+ *  - AES-256-CFB
+ *  - AES-128-CFB
+ *
+ * Defaults to ``AES-256-CTR``
  */